@@ -1,9 +1,12 @@
 use core::mem::swap;
 
+#[cfg(feature = "serde_support")]
+use serde::{Deserialize, Serialize};
+
 use self::heap_helpers::StaticHeapHole;
 pub use self::heap_helpers::StaticHeapPeekMut;
 pub use self::heap_iterators::{StaticHeapDrainSorted, StaticHeapIntoIterSorted};
-use crate::iterators::{StaticVecDrain, StaticVecIterConst};
+use crate::iterators::{StaticVecDrain, StaticVecIterConst, StaticVecIterMut};
 use crate::StaticVec;
 
 mod heap_helpers;
@@ -95,6 +98,7 @@ mod heap_trait_impls;
 /// [pop]: #method.pop
 /// [peek]: #method.peek
 /// [peek\_mut]: #method.peek_mut
+#[cfg_attr(feature = "serde_support", derive(Deserialize, Serialize))]
 pub struct StaticHeap<T, const N: usize> {
   pub(crate) data: StaticVec<T, N>,
 }
@@ -331,7 +335,7 @@ impl<T: Ord, const N: usize> StaticHeap<T, N> {
   // Using a hole reduces the constant factor compared to using swaps,
   // which involves twice as many moves.
   #[inline]
-  fn sift_up(&mut self, start: usize, position: usize) -> usize {
+  fn sift_up(&mut self, start: usize, position: usize) {
     unsafe {
       // Take out the value at `position` and create a hole.
       let mut hole = StaticHeapHole::new(&mut self.data, position);
@@ -342,7 +346,6 @@ impl<T: Ord, const N: usize> StaticHeap<T, N> {
         }
         hole.move_to(parent);
       }
-      hole.pos()
     }
   }
 
@@ -458,7 +461,7 @@ impl<T: Ord, const N: usize> StaticHeap<T, N> {
 }
 
 impl<T, const N: usize> StaticHeap<T, N> {
-  /// Returns an iterator visiting all values in the underlying StaticVec, in
+  /// Returns an iterator visiting all values in the StaticHeap's underlying StaticVec, in
   /// arbitrary order.
   ///
   /// # Examples
@@ -477,6 +480,28 @@ impl<T, const N: usize> StaticHeap<T, N> {
     self.data.iter()
   }
 
+  /// Returns a mutable iterator visiting all values in the StaticHeap's underlying StaticVec, in
+  /// arbitrary order.
+  ///
+  /// **Note:** Mutating the elements in a StaticHeap may cause it to become unbalanced.
+  ///
+  /// # Examples
+  ///
+  /// Basic usage:
+  /// ```
+  /// # use staticvec::*;
+  /// let mut heap = StaticHeap::from([1, 2, 3, 4]);
+  /// for i in heap.iter_mut() {
+  ///   *i *= 2;
+  /// }
+  /// // Prints "[2, 4, 6, 8]", but in arbitrary order
+  /// println!("{:?}", heap);
+  /// ```
+  #[inline(always)]
+  pub fn iter_mut(&mut self) -> StaticVecIterMut<'_, T, N> {
+    self.data.iter_mut()
+  }
+
   /// Returns an iterator which retrieves elements in heap order.
   /// This method consumes the original StaticHeap.
   ///
